@@ -38,7 +38,7 @@ class FFile:
 			self.json_ = json.loads(self.string_)
 			return self.json_
 		else:
-			print("File not exists")
+			return False
 
 	def create_file(self, content, override=True) -> None:
 		"""Scrive un nuovo file"""
@@ -55,4 +55,14 @@ class FFile:
 			with open(self.nomeFile, "a") as fa:
 				fa.write(content)
 		else:
-			print("File not exists")
\ No newline at end of file
+			return False
+
+	def append_json(self, content, to_key) -> None:
+		"""Aggiungi alla fine del file il contenuto"""
+		if self.__file_exists():
+			self.read_json()
+			self.json_[to_key] = content
+			with open(self.nomeFile, "a") as fa:
+				fa.write(self.json_)
+		else:
+			self.create_file(json.dump(content))
\ No newline at end of file
